@@ -12,6 +12,14 @@ current_dir=$(dirname -- "${BASH_SOURCE[0]}")
 
 source "${current_dir}/utilities.sh"
 
+# Helper function to filter out non-json output, for the type of output that we have below:
+# - any number of header lines may be printed that don't consist of '{'
+# - the json output starts with a single '{' and continues until the end of the file
+# The awk script below prints everything from the first '{' to the end of the file.
+function keep_json {
+    awk '/^{$/,EOF'
+}
+
 metadata_file=$(mktemp --tmpdir metadata.XXXXXXXXXX.json)
 create_metadata_file "${metadata_file}"
 
@@ -102,6 +110,7 @@ pika_test_options=(
 )
 
 index=0
+failures=0
 for executable in "${pika_targets[@]}"; do
     test_opts=${pika_test_options[$index]}
     raw_result_file=$(mktemp --tmpdir "${executable}_raw.XXXXXXXXXX.json")
@@ -116,21 +125,27 @@ for executable in "${pika_targets[@]}"; do
     exit_code=$?
     set -e
     if [[ ${exit_code} -ne 0 ]]; then
+        failures=$((failures + 1))
+
         echo "${executable} failed with exit code ${exit_code}"
+    else
+        # Append command and command line options
+        json_add_value_string "${result_file}" "metric.benchmark.command" "${executable}"
+        json_add_value_string "${result_file}" "metric.benchmark.command_options" "${test_opts}"
+
+        # Extract name and timing data from raw result file
+        benchmark_name=$(cat "${raw_result_file}" | keep_json | jq '.outputs[0].name')
+        benchmark_series=$(cat "${raw_result_file}" | keep_json | jq '.outputs[0].series')
+        json_add_value_json "${result_file}" "metric.benchmark.name" "${benchmark_name}"
+        json_add_value_json "${result_file}" "metric.benchmark.series" "${benchmark_series}"
+
+        json_merge "${metadata_file}" "${result_file}" "${result_file}"
+        submit_logstash "${result_file}"
     fi
 
-    # Append command and command line options
-    json_add_value_string "${result_file}" "metric.benchmark.command" "${executable}"
-    json_add_value_string "${result_file}" "metric.benchmark.command_options" "${test_opts}"
-
-    # Extract name and timing data from raw result file
-    benchmark_name=$(jq '.outputs[0].name' "${raw_result_file}")
-    benchmark_series=$(jq '.outputs[0].series' "${raw_result_file}")
-    json_add_value_json "${result_file}" "metric.benchmark.name" "${benchmark_name}"
-    json_add_value_json "${result_file}" "metric.benchmark.series" "${benchmark_series}"
-
-    json_merge "${metadata_file}" "${result_file}" "${result_file}"
-    submit_logstash "${result_file}"
-
     index=$((index + 1))
 done
+
+if ((failures > 0)); then
+    exit 1
+fi
