@@ -15,13 +15,13 @@
 
 namespace pika::cuda::experimental {
     namespace detail {
-        PIKA_EXPORT const char* cusolver_get_error_string(cusolverStatus_t error);
+        PIKA_EXPORT char const* cusolver_get_error_string(cusolverStatus_t error);
     }    // namespace detail
 
     struct cusolver_exception : pika::exception
     {
         PIKA_EXPORT explicit cusolver_exception(cusolverStatus_t err);
-        PIKA_EXPORT cusolver_exception(const std::string& msg, cusolverStatus_t err);
+        PIKA_EXPORT cusolver_exception(std::string const& msg, cusolverStatus_t err);
         PIKA_EXPORT cusolverStatus_t get_cusolver_errorcode() const noexcept;
 
     protected:
