@@ -12,7 +12,6 @@
 #include <pika/debugging/print.hpp>
 
 namespace pika::cuda::experimental::detail {
-    using namespace pika::debug::detail;
     template <int Level>
-    static print_threshold<Level, 0> cud_debug("CUDA-EX");
+    inline constexpr pika::debug::detail::print_threshold<Level, 0> cud_debug("CUDA-EX");
 }    // namespace pika::cuda::experimental::detail
