@@ -72,7 +72,7 @@ std::unique_ptr<pika::counting_semaphore<>> limiter;
 // a debug level of zero disables messages with a priority>0
 // a debug level of N shows messages with priority<N
 template <int Level>
-static print_threshold<Level, 0> msr_deb("MPI_SR_");
+inline constexpr print_threshold<Level, 0> msr_deb("MPI_SR_");
 
 // ------------------------------------------------------------
 // caution: message_buffers will be constructed in-place in a buffer
@@ -133,12 +133,12 @@ enum class msg_type : std::uint32_t
 // ------------------------------------------------------------
 // utility function to print out info after send/recv completes
 void msg_info(
-    std::uint32_t rank, std::uint32_t size, msg_type mtype, header h, const char* xmsg = nullptr)
+    std::uint32_t rank, std::uint32_t size, msg_type mtype, header h, char const* xmsg = nullptr)
 {
     if (output)
     {
         int other = (mtype == msg_type::send) ? next_rank(rank, size) : prev_rank(rank, size);
-        const char* msg = (mtype == msg_type::send) ? "send" : "recv";
+        char const* msg = (mtype == msg_type::send) ? "send" : "recv";
         std::stringstream temp;
         temp << dec<3>(rank) << "/" << dec<3>(size);
         // clang-format off
@@ -328,10 +328,8 @@ struct message_receiver
 // this is called on a pika thread after the runtime starts up
 int pika_main(pika::program_options::variables_map& vm)
 {
-    // Do not initialize mpi (we do that ourselves), do install an error handler
-    mpix::init(false, true);
-    // Setup mpi polling on default pool, enable exceptions and init mpi internals
-    mpix::register_polling();
+    // Enable polling on mpi pool, install an error handler
+    mpix::enable_polling enable_polling(mpix::exception_mode::install_handler);
     //
     std::int32_t rank, size;
     MPI_Comm_size(MPI_COMM_WORLD, &size);
@@ -360,7 +358,7 @@ int pika_main(pika::program_options::variables_map& vm)
     limiter = std::make_unique<pika::counting_semaphore<>>(in_flight);
 
     mpi_poll_size = vm["mpi-polling-size"].as<std::uint32_t>();
-    mpix::set_max_polling_size(mpi_poll_size);
+    mpix::detail::set_max_polling_size(mpi_poll_size);
 
     std::uint32_t message_size = vm["message-bytes"].as<std::uint32_t>();
 
@@ -478,20 +476,6 @@ int pika_main(pika::program_options::variables_map& vm)
     return EXIT_SUCCESS;
 }
 
-//----------------------------------------------------------------------------
-void init_resource_partitioner_handler(
-    pika::resource::partitioner&, pika::program_options::variables_map const& vm)
-{
-    // Don't create an MPI pool if the user disabled it
-    auto pool_mode = mpix::pool_create_mode::pika_decides;
-    if (vm["no-mpi-pool"].as<bool>()) { pool_mode = mpix::pool_create_mode::force_no_create; }
-
-    mpix::enable_optimizations(vm["mpi-optimizations"].as<bool>());
-
-    msr_deb<2>.debug(str<>("init RP"), "create_pool");
-    mpix::create_pool("", pool_mode);
-}
-
 //----------------------------------------------------------------------------
 // the normal int main function that is called at startup and runs on an OS
 // thread the user must call pika::init to start the pika runtime which
@@ -564,8 +548,8 @@ int main(int argc, char* argv[])
     // Initialize and run pika.
     pika::init_params init_args;
     init_args.desc_cmdline = cmdline;
-    // Set the callback to init thread_pools
-    init_args.rp_callback = &init_resource_partitioner_handler;
+
+    mpix::enable_optimizations(vm["mpi-optimizations"].as<bool>());
 
     auto result = pika::init(pika_main, argc, argv, init_args);
     PIKA_TEST_EQ(result, 0);
