@@ -123,47 +123,6 @@ namespace pika::concurrency::detail {
 
         pair lrs(std::memory_order mo = std::memory_order_acquire) const { return pair_.load(mo); }
 
-        node* left(std::memory_order mo = std::memory_order_acquire) const
-        {
-            return pair_.load(mo).get_left_ptr();
-        }
-
-        node* right(std::memory_order mo = std::memory_order_acquire) const
-        {
-            return pair_.load(mo).get_right_ptr();
-        }
-
-        tag_t status(std::memory_order mo = std::memory_order_acquire) const
-        {
-            return pair_.load(mo).get_left_tag();
-        }
-
-        tag_t tag(std::memory_order mo = std::memory_order_acquire) const
-        {
-            return pair_.load(mo).get_right_tag();
-        }
-
-        bool cas(deque_anchor& expected, deque_anchor const& desired,
-            std::memory_order mo = std::memory_order_acq_rel)
-        {
-            return pair_.compare_exchange_strong(expected.load(std::memory_order_acquire),
-                desired.load(std::memory_order_acquire), mo);
-        }
-
-        bool cas(pair& expected, deque_anchor const& desired,
-            std::memory_order mo = std::memory_order_acq_rel)
-        {
-            return pair_.compare_exchange_strong(
-                expected, desired.load(std::memory_order_acquire), mo);
-        }
-
-        bool cas(deque_anchor& expected, pair const& desired,
-            std::memory_order mo = std::memory_order_acq_rel)
-        {
-            return pair_.compare_exchange_strong(
-                expected.load(std::memory_order_acquire), desired, mo);
-        }
-
         bool cas(
             pair& expected, pair const& desired, std::memory_order mo = std::memory_order_acq_rel)
         {
