@@ -273,7 +273,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
     }
 
     template <typename... Args>
-    void tuple_print(std::ostream& os, const std::tuple<Args...>& t)
+    void tuple_print(std::ostream& os, std::tuple<Args...> const& t)
     {
         tuple_print(os, t, std::make_index_sequence<sizeof...(Args)>());
     }
@@ -427,7 +427,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
     template <>
     struct enable_print<false>
     {
-        constexpr enable_print(const char*) {}
+        constexpr enable_print(char const*) {}
 
         constexpr bool is_enabled() const { return false; }
 
@@ -484,19 +484,19 @@ namespace PIKA_DETAIL_NS_DEBUG {
         }
 
         template <typename T, typename V>
-        constexpr void set(T&, V const&)
+        static constexpr void set(T&, V const&)
         {
         }
 
         // @todo, return void so that timers have zero footprint when disabled
         template <typename... Args>
-        constexpr empty_timed_var make_timer(const double, Args const&...) const
+        constexpr empty_timed_var make_timer(double const, Args const&...) const
         {
             return empty_timed_var{};
         }
 
         template <typename Expr>
-        constexpr bool eval(Expr const&)
+        constexpr bool eval(Expr const&) const
         {
             return true;
         }
@@ -518,7 +518,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
         {
         }
 
-        constexpr enable_print(const char* p)
+        constexpr enable_print(char const* p)
           : prefix_(p)
         {
         }
@@ -586,19 +586,19 @@ namespace PIKA_DETAIL_NS_DEBUG {
         }
 
         template <typename T, typename V>
-        void set(T& var, V const& val)
+        static void set(T& var, V const& val)
         {
             var = val;
         }
 
         template <typename... Args>
-        constexpr timed_var<Args...> make_timer(const double delay, const Args... args) const
+        constexpr timed_var<Args...> make_timer(double const delay, const Args... args) const
         {
             return timed_var<Args...>(delay, args...);
         }
 
         template <typename Expr>
-        auto eval(Expr const& e)
+        auto eval(Expr const& e) const
         {
             return e();
         }
