@@ -138,9 +138,12 @@ namespace pika {
             pika::util::detail::set_spinlock_deadlock_warning_limit(
                 cmdline.rtcfg_.get_spinlock_deadlock_warning_limit());
 #endif
-#ifdef PIKA_HAVE_MPI
-            pika::mpi::experimental::set_completion_mode(pika::detail::get_entry_as<std::size_t>(
-                cmdline.rtcfg_, "pika.mpi.completion_mode", 0));
+#if defined(PIKA_HAVE_MPI)
+            pika::mpi::experimental::detail::set_pool_enabled(
+                pika::detail::get_entry_as<bool>(cmdline.rtcfg_, "pika.mpi.enable_pool", false));
+            pika::mpi::experimental::detail::set_completion_mode(
+                pika::detail::get_entry_as<std::size_t>(
+                    cmdline.rtcfg_, "pika.mpi.completion_mode", 0));
 #endif
             init_logging(cmdline.rtcfg_);
         }
@@ -284,7 +287,7 @@ namespace pika {
         ///////////////////////////////////////////////////////////////////////
         int run_or_start(
             pika::util::detail::function<int(pika::program_options::variables_map& vm)> const& f,
-            int argc, const char* const* argv, init_params const& params, bool blocking)
+            int argc, char const* const* argv, init_params const& params, bool blocking)
         {
             if (pika::detail::get_runtime_ptr() != nullptr)
             {
@@ -321,6 +324,12 @@ namespace pika {
             case command_line_handling_result::exit: return 0;
             }
 
+#if defined(PIKA_HAVE_MPI)
+            if (mpi::experimental::detail::get_pool_enabled())
+                mpi::experimental::detail::init_resource_partitioner_handler(rp, cmdline.vm_,
+                    mpi::experimental::polling_pool_creation_mode::mode_pika_decides);
+#endif
+
             // If thread_pools initialization in user main
             if (params.rp_callback) { params.rp_callback(rp, cmdline.vm_); }
 
@@ -348,7 +357,7 @@ namespace pika {
 
         int init_start_impl(
             pika::util::detail::function<int(pika::program_options::variables_map&)> f, int argc,
-            const char* const* argv, init_params const& params, bool blocking)
+            char const* const* argv, init_params const& params, bool blocking)
         {
             if (argc == 0 || argv == nullptr)
             {
@@ -370,12 +379,12 @@ namespace pika {
     }    // namespace detail
 
     int init(std::function<int(pika::program_options::variables_map&)> f, int argc,
-        const char* const* argv, init_params const& params)
+        char const* const* argv, init_params const& params)
     {
         return detail::init_start_impl(PIKA_MOVE(f), argc, argv, params, true);
     }
 
-    int init(std::function<int(int, char**)> f, int argc, const char* const* argv,
+    int init(std::function<int(int, char**)> f, int argc, char const* const* argv,
         init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f =
@@ -383,21 +392,21 @@ namespace pika {
         return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
     }
 
-    int init(std::function<int()> f, int argc, const char* const* argv, init_params const& params)
+    int init(std::function<int()> f, int argc, char const* const* argv, init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f =
             pika::util::detail::bind(f);
         return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
     }
 
-    int init(std::nullptr_t, int argc, const char* const* argv, init_params const& params)
+    int init(std::nullptr_t, int argc, char const* const* argv, init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f;
         return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
     }
 
     void start(std::function<int(pika::program_options::variables_map&)> f, int argc,
-        const char* const* argv, init_params const& params)
+        char const* const* argv, init_params const& params)
     {
         if (detail::init_start_impl(PIKA_MOVE(f), argc, argv, params, false) != 0)
         {
@@ -405,7 +414,7 @@ namespace pika {
         }
     }
 
-    void start(std::function<int(int, char**)> f, int argc, const char* const* argv,
+    void start(std::function<int(int, char**)> f, int argc, char const* const* argv,
         init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f =
@@ -416,7 +425,7 @@ namespace pika {
         }
     }
 
-    void start(std::function<int()> f, int argc, const char* const* argv, init_params const& params)
+    void start(std::function<int()> f, int argc, char const* const* argv, init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f =
             pika::util::detail::bind(f);
@@ -426,7 +435,7 @@ namespace pika {
         }
     }
 
-    void start(std::nullptr_t, int argc, const char* const* argv, init_params const& params)
+    void start(std::nullptr_t, int argc, char const* const* argv, init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f;
         if (detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false) != 0)
@@ -435,7 +444,7 @@ namespace pika {
         }
     }
 
-    void start(int argc, const char* const* argv, init_params const& params)
+    void start(int argc, char const* const* argv, init_params const& params)
     {
         pika::util::detail::function<int(pika::program_options::variables_map&)> main_f;
         if (detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false) != 0)
