@@ -33,7 +33,7 @@ namespace pika::program_options {
 
     namespace {
 
-        woption woption_from_option(const option& opt)
+        woption woption_from_option(option const& opt)
         {
             woption result;
             result.string_key = opt.string_key;
@@ -49,24 +49,24 @@ namespace pika::program_options {
         }
     }    // namespace
 
-    basic_parsed_options<wchar_t>::basic_parsed_options(const parsed_options& po)
+    basic_parsed_options<wchar_t>::basic_parsed_options(parsed_options const& po)
       : description(po.description)
       , utf8_encoded_options(po)
       , m_options_prefix(po.m_options_prefix)
     {
-        for (const auto& option : po.options) options.push_back(woption_from_option(option));
+        for (auto const& option : po.options) options.push_back(woption_from_option(option));
     }
 
     template <class Char>
     basic_parsed_options<Char> parse_config_file(
-        std::basic_istream<Char>& is, const options_description& desc, bool allow_unregistered)
+        std::basic_istream<Char>& is, options_description const& desc, bool allow_unregistered)
     {
         set<string> allowed_options;
 
-        const vector<shared_ptr<option_description>>& options = desc.options();
-        for (const auto& option : options)
+        vector<shared_ptr<option_description>> const& options = desc.options();
+        for (auto const& option : options)
         {
-            const option_description& d = *option;
+            option_description const& d = *option;
 
             if (d.long_name().empty())
                 throw error(
@@ -84,14 +84,14 @@ namespace pika::program_options {
     }
 
     template PIKA_EXPORT basic_parsed_options<char> parse_config_file(
-        std::basic_istream<char>& is, const options_description& desc, bool allow_unregistered);
+        std::basic_istream<char>& is, options_description const& desc, bool allow_unregistered);
 
     template PIKA_EXPORT basic_parsed_options<wchar_t> parse_config_file(
-        std::basic_istream<wchar_t>& is, const options_description& desc, bool allow_unregistered);
+        std::basic_istream<wchar_t>& is, options_description const& desc, bool allow_unregistered);
 
     template <class Char>
     basic_parsed_options<Char> parse_config_file(
-        const char* filename, const options_description& desc, bool allow_unregistered)
+        char const* filename, options_description const& desc, bool allow_unregistered)
     {
         // Parser return char strings
         std::basic_ifstream<Char> strm(filename);
@@ -105,13 +105,13 @@ namespace pika::program_options {
     }
 
     template PIKA_EXPORT basic_parsed_options<char> parse_config_file(
-        const char* filename, const options_description& desc, bool allow_unregistered);
+        char const* filename, options_description const& desc, bool allow_unregistered);
 
     template PIKA_EXPORT basic_parsed_options<wchar_t> parse_config_file(
-        const char* filename, const options_description& desc, bool allow_unregistered);
+        char const* filename, options_description const& desc, bool allow_unregistered);
 
     parsed_options parse_environment(
-        const options_description& desc, const std::function<std::string(std::string)>& name_mapper)
+        options_description const& desc, std::function<std::string(std::string)> const& name_mapper)
     {
         parsed_options result(&desc);
 
@@ -141,12 +141,12 @@ namespace pika::program_options {
         class prefix_name_mapper
         {
         public:
-            prefix_name_mapper(const std::string& prefix)
+            prefix_name_mapper(std::string const& prefix)
               : prefix(prefix)
             {
             }
 
-            std::string operator()(const std::string& s)
+            std::string operator()(std::string const& s)
             {
                 string result;
                 if (s.find(prefix) == 0)
@@ -166,12 +166,12 @@ namespace pika::program_options {
         };
     }    // namespace detail
 
-    parsed_options parse_environment(const options_description& desc, const std::string& prefix)
+    parsed_options parse_environment(options_description const& desc, std::string const& prefix)
     {
         return parse_environment(desc, detail::prefix_name_mapper(prefix));
     }
 
-    parsed_options parse_environment(const options_description& desc, const char* prefix)
+    parsed_options parse_environment(options_description const& desc, char const* prefix)
     {
         return parse_environment(desc, string(prefix));
     }
