@@ -42,6 +42,7 @@
 
 #if defined(PIKA_HAVE_MPI)
 # include <pika/mpi_base/mpi.hpp>
+# include <pika/mpi_base/mpi_environment.hpp>
 #endif
 
 #if defined(PIKA_HAVE_TRACY)
@@ -905,15 +906,8 @@ namespace pika::detail {
             strm << std::string(79, '*') << '\n';
 
 #if defined(PIKA_HAVE_MPI)
-            int mpi_initialized = 0;
-            if (MPI_Initialized(&mpi_initialized) == MPI_SUCCESS && mpi_initialized)
-            {
-                int rank = 0;
-                if (MPI_Comm_rank(MPI_COMM_WORLD, &rank) == MPI_SUCCESS)
-                {
-                    strm << "MPI rank: " << rank << '\n';
-                }
-            }
+            if (mpi::detail::environment::is_mpi_initialized())
+                strm << "MPI rank: " << mpi::detail::environment::rank() << '\n';
 #endif
 
             for (std::size_t i = 0; i != num_threads; ++i)
@@ -1027,11 +1021,11 @@ namespace pika::detail {
 
             // Always report the exception early in case the runtime becomes deadlocked because of the
             // thrown exception and isn't able to shut down.
-            fmt::print(std::cerr,
+            PIKA_LOG(warn,
                 "The pika runtime caught the following exception in the entry point (typically "
                 "pika_main). The exception may be rethrown later by pika::init or pika::stop. The "
                 "pika runtime will wait for all tasks to finish, but may be deadlocked because of "
-                "the exception.\n");
+                "the exception.");
             detail::report_exception_and_continue(exception_);
 
             // Then call user-registered error handlers if available.
