@@ -6,7 +6,7 @@
 
 #include <pika/config.hpp>
 #include <pika/allocator_support/internal_allocator.hpp>
-#include <pika/modules/logging.hpp>
+#include <pika/logging.hpp>
 #include <pika/threading_base/thread_data.hpp>
 
 #include <fmt/format.h>
@@ -17,7 +17,7 @@ namespace pika::threads::detail {
 
     thread_data_stackless::~thread_data_stackless()
     {
-        LTM_(debug).format("~thread_data_stackless({}), description({}), phase({})", fmt::ptr(this),
+        PIKA_LOG(debug, "~thread_data_stackless({}), description({}), phase({})", fmt::ptr(this),
             this->get_description(), this->get_thread_phase());
     }
 }    // namespace pika::threads::detail
