@@ -48,7 +48,7 @@ private:
         stage_tasks_functor& outer;
 
     public:
-        void operator()(const tbb::blocked_range<std::uint64_t>& r) const
+        void operator()(tbb::blocked_range<std::uint64_t> const& r) const
         {
             for (std::uint64_t i = r.begin(); i != r.end(); ++i)
             {
